clear all

/* Set root directory */
*global dir " " //set origin path
global code "$dir/replication_package/codes"
global survey_data "$dir/replication_package/data"
global output "$dir/replication_package/output"
global figures "$output/figures"
global tables "$output/tables"


*import and clean data
do "$code/data_cleaning/creating_dataset_A"

grstyle init
grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"

*generate variables used in the analysis
gen rep=0 if !missing( political_agg)
replace rep=1 if political_agg==2
label var rep "Republican"

gen ind=0 if !missing( political_agg)
replace ind=1 if political_agg==3
label var ind "Independent and Others"


tab inf_wage_theories, gen(inf_wage_theories_)


**# TABLEA1: WAGE INCREASE DUE TO JOB CHANGE OVER REASONS FOR WAGE INCREASE
*regress an indicator equal to 1 when "Wage increase primarily due to career progression" on demographics and on an indicator equal to 1 when "Wage increase due to job change"
**Note: The sample is limited to those respondents who received a wage increase and then answered to the question on reasons for the wage increase
{
eststo clear
global table_name "$tables/TABLE_A1"

* Table end
file open  holder using $tables/temp_end.tex, write replace text
file write holder "\hline \hline \end{tabular}" _n
file close holder

* Table start
file open holder using $table_name.tex, write replace text
file write holder "\begin{tabular}{lc} " _n
file write holder "& \multicolumn{1}{c}{ \textit{Dependent variable:}}  \\" _n
file write holder "&Wage increase primarily due to \\ " _n
file write holder "&career progression \\ \hline" _n
file close holder

	
global controls_main women age_class_agg2 age_class_agg3 dummy_race_agg2 dummy_race_agg3 dummy_race_agg4 incomegroup_agg_2 incomegroup_agg_3 dummy_children dummy_us_area1 dummy_us_area2 dummy_us_area3 college rep ind

label var dummy_jobch_yes_wage_onjob_en_ow "Wage increase due to job change"
label var dummy_job_change_en "Changed job in last two years"

	
eststo clear
eststo: reg dummy_career_progression dummy_jobch_yes_wage_onjob_en_ow $controls_main , vce(robust)
local r1: display %5.3f `e(r2_a)'

qui sum dummy_career_progression if e(sample) 
local mean1: display %5.3f `r(mean)'
local obs1: display %5.0f `r(N)'
local sd1: display %5.3f `r(sd)'

esttab using $tables/panel.tex, replace fragment booktabs noconst nobase label cells(b(fmt(3) star) se(par fmt(3))) collabels(none) /// 
starlevels(* .1 ** .05 *** .01) se nonumbers nomtitles nolines nocon noobs compress

eststo clear

*** Means ***
file open holder using $tables/panel_means.tex, write replace text
file write holder "\hline " _n
file write holder "Observations & `obs1' \\" _n     
file write holder "Adj. R$^{2}$ & `r1'     \\" _n 
file write holder "Dependent variable mean & `mean1'    \\" _n   
file write holder "Dependent variable std. dev. & `sd1'  \\" _n
file close holder

appendfile $tables/panel.tex $table_name.tex
appendfile $tables/panel_means.tex $table_name.tex
appendfile $tables/temp_end.tex $table_name.tex

erase $tables/panel.tex
erase $tables/panel_means.tex
erase $tables/temp_end.tex 

eststo clear
}
